@@ -9,6 +9,17 @@ from nctoolkit.session import remove_safe
 def boxstat(self, stat="mean", x=1, y=1):
     """Method to calculate the spatial stat from a dataset"""
 
+
+    if not isinstance(x, int):
+        raise ValueError("x should be int")
+    if not isinstance(y, int):
+        raise ValueError("y should be int")
+
+    if x <= 0:
+        raise ValueError("x should be positive")
+    if y <= 0:
+        raise ValueError("y should be positive")
+
     if len(self) == 0:
         raise ValueError("Failure due to empty dataset!")
 
@@ -301,7 +312,7 @@ def spatial_percentile(self, p=None):
     if p is None:
         raise ValueError("Please supply a percentile")
 
-    if type(p) not in (int, float):
+    if not isinstance(p, (int, float)):
         raise ValueError(f"{str(p)} is not a valid percentile")
     if (p < 0) or (p > 100):
         raise ValueError(f"p: {str(p)} is not between 0 and 100!")
