@@ -31,7 +31,7 @@ def nco_command(self, command=None, ensemble=False):
     if command is None:
         raise ValueError("Please supply a command")
 
-    if type(command) is not str:
+    if not isinstance(command, str):
         raise TypeError("Command supplied is not a str")
 
     if (
@@ -123,6 +123,10 @@ def nco_command(self, command=None, ensemble=False):
             self.history.append(cc)
         self._hold_history = copy.deepcopy(self.history)
 
+        for ff in target_list:
+            remove_safe(ff)
+        for ff in target_list:
+            remove_safe(ff)
 
 
 
