@@ -396,6 +396,14 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                 f"None of the months supplied are in the dataset. Please check months supplied to nctoolkit methods!"
             )
 
+        text = re.compile(r"month [0-9]* not found")
+        errors = text.findall(error)
+        if len(errors) > 0:
+            error = errors[0]
+            raise ValueError(
+                f"None of the months supplied are in the dataset. Please check months supplied to nctoolkit methods!"
+            )
+
         text = re.compile(r"Year [0-9]* not found")
         errors = text.findall(error)
         if len(errors) > 0:
@@ -412,6 +420,7 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                 f"None of the days supplied are available. Please check days supplied to nctoolkit methods!"
             )
 
+
         text = re.compile(r"Timestep [0-9]* not found")
         errors = text.findall(error)
         if len(errors) > 0:
@@ -481,7 +490,7 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                         in str(result)
                     ):
                         raise ValueError(
-                            "CDO error: Error (cdf_put_vara_double): NetCDF: Numeric conversion not representable. Tip: check if missing values are incorrectly set to large actual values!"
+                            "CDO error: Error (cdf_put_vara_double): NetCDF: Numeric conversion not representable. Tip: Consider changing numerical precision using set_precision or check if missing values are incorrectly set to large actual values!"
                         )
 
                     raise ValueError(
@@ -602,10 +611,24 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
     sel_hour = []
     sel_var = []
 
+
+    drop_warnings = []
+
     for x in result.decode("utf-8").lower().split("\n"):
         warned = False
         ignore = False
 
+        text = re.compile("delete \(warning\): month >[0-9]*< not found!")
+        errors = text.findall(x)
+        if len(errors) > 0:
+            for y in errors:
+                for z in re.findall(r'\d+', y):
+                    drop_warnings.append(z)
+                    #message= f"Warning: Unable to find month {z}"
+                    #warnings.warn(message)
+                    ignore = True
+
+
         if "selyear" in x:
             text = re.compile("selyear \\(warning\\): year [0-9]* not found")
             all_text = text.findall(x)
@@ -733,22 +756,28 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
                 text = re.compile(
                     "unknown units \[.*\] supplied for grid cell corner .*; proceeding assuming .*!"
                 )
-                text_find = text.findall(
-                    "CDO warning: cdo(1) gridarea (warning): unknown units [degrees] supplied for grid cell corner longitudes; proceeding assuming radians!"
-                )
+                text_find = text.findall(x)
                 if len(text_find) > 0:
                     message = text_find[0]
                     message = "Warning for grid area calculations: " + message
                     warnings.warn(message)
                     warned = True
 
+                text = re.compile(
+                    "delete \(warning\): timestep .* not found"
+                )
+                text_find = text.findall(x)
+                if len(text_find) > 0:
+                    message = text_find[0]
+                    message = "Warning: attempting to drop non-existent timesteps!"
+                    warnings.warn(message)
+                    warned = True
+
             ## Unsupported array structure message
             if "unsupported" in x and "skipped variable" in x:
                 text = re.compile("skipped variable .*!")
                 bad_var = (
-                    text.findall(
-                        "CDO warning: warning (cdfscanvarattr): time must be the first dimension! unsupported array structure, skipped variable fgco2_reg!"
-                    )[0]
+                    text.findall(x)[0]
                     .split(" ")[2]
                     .replace("!", "")
                 )
@@ -778,6 +807,10 @@ def run_cdo(command=None, target=None, out_file=None, overwrite=False, precision
             if not warned:
                 if "arning" in x:
                     warnings.warn(f"CDO warning: {x}")
+    if len(drop_warnings) > 0:
+        message = ",".join(drop_warnings)
+        message = f"The following months do not exist in the dataset: {message}"
+        warnings.warn(message)
 
     if len(sel_timestep) > 0:
         len_sel = len(sel_timestep)
